@@ -17,13 +17,13 @@
 
 #include "bootentry.h"
 
-#include <QAbstractItemView>
-#include <QFile>
+#include <QFileInfo>
 
 // BootEntry
 
 // private:
 
+QString BootEntry::m_problem = "";
 QStringList BootEntry::m_list = QStringList();
 
 // public:
@@ -32,18 +32,44 @@ QStringList BootEntry::getList() {
 	if (!m_list.isEmpty())
 		return m_list;
 
-	m_list += i18n("Default System");
+	m_problem = ""; // reset
+
+	QFile grubConfigFile("/boot/grub/grub.cfg");
+	QFileInfo grubConfigFileInfo(grubConfigFile);
+	if (!grubConfigFileInfo.isReadable()) {
+/*
+		m_problem += i18n("No permissions to read GRUB menu entries.");
+		m_problem += '\n';
+		m_problem += grubConfigFile.fileName();
+		m_problem += "\n\n";
+		m_problem += i18n("Quick fix: %0").arg("sudo chmod 0604 grub.cfg");
+*/
+
+		return m_list;
+	}
 
-	QString grubConfigPath = "/boot/grub/grub.cfg";
-	QFile grubConfigFile(grubConfigPath);
 	if (grubConfigFile.open(QFile::ReadOnly)) {
+		bool inSubmenu = false;
 		QTextStream text(&grubConfigFile);
 		QString menuEntryID = "menuentry ";
 		QString line;
 		while (!(line = text.readLine()).isNull()) {
+// FIXME: the parser assumes that the grub.cfg formatting is sane
+			if (inSubmenu && (line == "}")/* use non-simplified line */) {
+				inSubmenu = false;
+
+				continue; // while
+			}
+
 			line = line.simplified();
 
-			if (!line.startsWith(menuEntryID))
+			if (!inSubmenu && line.startsWith("submenu ")) {
+				inSubmenu = true;
+
+				continue; // while
+			}
+
+			if (inSubmenu || !line.startsWith(menuEntryID))
 				continue; // while
 			
 			line = line.mid(menuEntryID.length());
@@ -69,13 +95,26 @@ QStringList BootEntry::getList() {
 				line = line.mid(quoteStart, quoteEnd);
 			else
 				U_ERROR << "Error parsing menuentry: " << line U_END;
-			
-			U_DEBUG << line U_END;
-			m_list << line;
+
+			if (line.contains("(memtest86+")) {
+				U_DEBUG << "Skipping Boot Entry: " << line U_END;
+			}
+			else {
+				U_DEBUG << "Adding Boot Entry: " << line U_END;
+				m_list << line;
+			}
 		}
 	}
 	else {
-		U_ERROR << "Could not read GRUB menu entries: " << grubConfigPath U_END;
+		U_ERROR << "Could not read GRUB menu entries: " << grubConfigFile.fileName() U_END;
+	}
+
+	if (m_list.isEmpty()) {
+/*
+		m_problem += i18n("Could not find any boot entries.");
+		m_problem += '\n';
+*/
+		m_problem += grubConfigFile.fileName();
 	}
 
 	return m_list;
@@ -86,9 +125,16 @@ QStringList BootEntry::getList() {
 // public:
 
 BootEntryAction::BootEntryAction(const QString &name) :
-	U_ACTION(0),
+	U_ACTION(nullptr),
 	m_name(name) {
 	setText(name);
+	connect(this, SIGNAL(triggered()), SLOT(onAction()));
+}
+
+// private slots:
+
+void BootEntryAction::onAction() {
+	U_DEBUG << m_name U_END;
 }
 
 // BootEntryComboBox
@@ -97,7 +143,10 @@ BootEntryAction::BootEntryAction(const QString &name) :
 
 BootEntryComboBox::BootEntryComboBox() :
 	U_COMBO_BOX() {
+	//setToolTip(i18n("Select an Operating System you want to use after restart"));
 	view()->setAlternatingRowColors(true);
+
+	//addItem('<' + i18n("Default") + '>');
 	addItems(BootEntry::getList());
 }
 
@@ -107,4 +156,24 @@ BootEntryComboBox::BootEntryComboBox() :
 
 BootEntryMenu::BootEntryMenu(QWidget *parent) :
 	U_MENU(i18n("Restart Computer"), parent) {
+
+	QStringList entryList = BootEntry::getList(); // 1.
+
+	if (!BootEntry::getProblem().isEmpty()) { // 2.
+		addAction(
+			U_STOCK_ICON("dialog-error"), i18n("Error"),
+			this, SLOT(onProblem())
+		);
+	}
+	else {
+		for (const QString &i : entryList) {
+			addAction(new BootEntryAction(i));
+		}
+	}
+}
+
+// private slots:
+
+void BootEntryMenu::onProblem() {
+	U_ERROR_MESSAGE(this, BootEntry::getProblem());
 }
