@@ -16,6 +16,8 @@
 // 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include "test.h"
+
+#include "../config.h"
 #include "../utils.h"
 
 #include <QFormLayout>
@@ -26,7 +28,7 @@
 
 TestAction::TestAction() :
 	Action(i18n("Show Message (no shutdown)"), "dialog-ok", "test"),
-	m_widget(0) {
+	m_widget(nullptr) {
 
 // TODO: sound beep
 
