@@ -20,13 +20,13 @@
 
 #include "../kshutdown.h"
 
-class U_EXPORT TestAction: public KShutdown::Action {
+class TestAction: public KShutdown::Action {
 public:
-	TestAction();
-	virtual QWidget *getWidget();
-	virtual bool onAction();
-	virtual void readConfig(const QString &group, Config *config);
-	virtual void writeConfig(const QString &group, Config *config);
+	explicit TestAction();
+	virtual QWidget *getWidget() override;
+	virtual bool onAction() override;
+	virtual void readConfig(Config *config) override;
+	virtual void writeConfig(Config *config) override;
 private:
 	Q_DISABLE_COPY(TestAction)
 	QString m_defaultText;
