@@ -15,9 +15,8 @@
 // with this program; if not, write to the Free Software Foundation, Inc.,
 // 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-#include "pureqt.h"
-
 #include "commandline.h"
+
 #include "mainwindow.h"
 #include "utils.h"
 
@@ -25,7 +24,7 @@
 
 bool TimeOption::m_absolute = false;
 bool TimeOption::m_relative = false;
-KShutdown::Action *TimeOption::m_action = 0;
+KShutdown::Action *TimeOption::m_action = nullptr;
 QString TimeOption::m_option = QString::null;
 QTime TimeOption::m_time = QTime();
 
