@@ -15,24 +15,25 @@
 // with this program; if not, write to the Free Software Foundation, Inc.,
 // 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
+#include "config.h"
+
 #include "pureqt.h"
+#include "utils.h"
+
+#ifdef KS_PURE_QT
+	#include <QDir>
+#endif // KS_PURE_QT
 
 #ifdef KS_KF5
 	#include <KConfig>
 	#include <KSharedConfig>
 #endif // KS_KF5
 
-#ifdef KS_PURE_QT
-	#include <QDir>
-	#include <QSettings>
-#endif // KS_PURE_QT
-
-#include "config.h"
-#include "utils.h"
+// Config
 
 // private
 
-Config *Config::m_user = 0;
+Config *Config::m_user = nullptr;
 
 // public
 
@@ -41,7 +42,7 @@ Config::~Config() {
 #ifdef KS_PURE_QT
 	if (m_engine) {
 		delete m_engine;
-		m_engine = 0;
+		m_engine = nullptr;
 	}
 #endif // KS_PURE_QT
 }
@@ -108,22 +109,6 @@ void Config::setProgressBarEnabled(const bool value) {
 	write("Progress Bar", "Enabled", value);
 }
 
-Qt::Alignment Config::progressBarAlignment() {
-	Config *config = user();
-	config->beginGroup("Progress Bar");
-	int result = config->read("Alignment", Qt::AlignTop).toInt();
-	config->endGroup();
-
-	return (Qt::Alignment)result;
-}
-
-void Config::setProgressBarAlignment(const Qt::Alignment value) {
-	Config *config = user();
-	config->beginGroup("Progress Bar");
-	config->write("Alignment", (int)value);
-	config->endGroup();
-}
-
 bool Config::systemTrayIconEnabled() {
 	#ifdef KS_KF5
 	return true;
@@ -185,7 +170,7 @@ void Config::sync() {
 // private
 
 Config::Config() :
-	QObject(0) {
+	QObject(nullptr) {
 
 	//U_DEBUG << "Config::Config()" U_END;
 	
@@ -204,3 +189,36 @@ Config::Config() :
 		m_engine = new QSettings();
 #endif // KS_NATIVE_KDE
 }
+
+// Var
+
+// public
+
+void Var::sync() {
+	QVariant value = variant();
+
+	Config *config = Config::user();
+	//U_DEBUG << "Sync var: " << m_group << " / " << m_key << " = " << value U_END;
+
+	config->beginGroup(m_group);
+	config->write(m_key, value);
+	config->endGroup();
+
+	config->sync();
+}
+
+// private
+
+QVariant Var::variant() {
+	if (!m_lazyVariant.isValid()) {
+		Config *config = Config::user();
+
+		config->beginGroup(m_group);
+		m_lazyVariant = config->read(m_key, m_defaultVariant);
+		config->endGroup();
+
+		//U_DEBUG << "Read var: " << m_group << " / " << m_key << " = " << m_lazyVariant U_END;
+	}
+	
+	return m_lazyVariant;
+}
