@@ -15,20 +15,14 @@
 // with this program; if not, write to the Free Software Foundation, Inc.,
 // 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-#include "pureqt.h"
+#include "infowidget.h"
 
-#ifdef KS_NATIVE_KDE
-	#include <KMessageWidget>
-#endif // KS_NATIVE_KDE
+#include "utils.h"
 
 #include <QDesktopServices>
 #include <QHBoxLayout>
-#include <QLabel>
 #include <QUrl>
 
-#include "infowidget.h"
-#include "utils.h"
-
 // public
 
 InfoWidget::InfoWidget(QWidget *parent) :
@@ -37,7 +31,7 @@ InfoWidget::InfoWidget(QWidget *parent) :
 	setObjectName("info-widget");
 	setVisible(false);
 
-	QHBoxLayout *mainLayout = new QHBoxLayout(this);
+	auto *mainLayout = new QHBoxLayout(this);
 
 #ifdef KS_NATIVE_KDE
 	m_messageWidget = new KMessageWidget(this);
@@ -69,7 +63,7 @@ InfoWidget::InfoWidget(QWidget *parent) :
 #endif // KS_NATIVE_KDE
 }
 
-InfoWidget::~InfoWidget() { }
+InfoWidget::~InfoWidget() = default;
 
 void InfoWidget::setText(const QString &text, const Type type) {
 #ifdef KS_NATIVE_KDE
@@ -145,11 +139,13 @@ void InfoWidget::onLinkActivated(const QString &contents) {
 #ifdef KS_PURE_QT
 #ifdef Q_OS_WIN32
 void InfoWidget::setIcon(const QStyle::StandardPixmap standardIcon) {
-	m_icon->setPixmap(U_APP->style()->standardIcon(standardIcon).pixmap(24, 24));
+	int size = U_APP->style()->pixelMetric(QStyle::PM_MessageBoxIconSize);
+	m_icon->setPixmap(U_APP->style()->standardIcon(standardIcon).pixmap(size, size));
 }
 #else
 void InfoWidget::setIcon(const QString &iconName) {
-	m_icon->setPixmap(U_STOCK_ICON(iconName).pixmap(24, 24));
+	int size = U_APP->style()->pixelMetric(QStyle::PM_MessageBoxIconSize);
+	m_icon->setPixmap(U_STOCK_ICON(iconName).pixmap(size, size));
 }
 #endif // Q_OS_WIN32
 #endif // KS_PURE_QT
