@@ -15,54 +15,54 @@
 // with this program; if not, write to the Free Software Foundation, Inc.,
 // 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-#include "pureqt.h"
+#include "kshutdown.h"
 
-#ifdef KS_UNIX
-	#include <errno.h>
-	#include <signal.h>
-#endif // KS_UNIX
+#include "config.h"
+#include "log.h"
+#include "mainwindow.h"
+#include "password.h"
+#include "progressbar.h"
+#include "pureqt.h"
+#include "utils.h"
+#include "actions/bootentry.h"
+#include "actions/lock.h"
 
 #include <QPointer>
-#include <QProcess>
+#include <QPushButton>
+
+#ifdef KS_UNIX
+	#include <csignal> // for ::kill
+
+	#if QT_VERSION >= 0x050000
+		#include <QThread>
+	#else
+		#include <unistd.h> // for ::sleep
+	#endif // QT_VERSION
+#endif // KS_UNIX
+
 #ifdef Q_OS_WIN32
 	#ifndef WIN32_LEAN_AND_MEAN
 		#define WIN32_LEAN_AND_MEAN
 	#endif // WIN32_LEAN_AND_MEAN
 	#include <windows.h>
 	#include <powrprof.h>
-#else
-	#include <unistd.h> // for sleep
 #endif // Q_OS_WIN32
 
-#ifdef KS_DBUS
-	#include <QDBusInterface>
-	#include <QDBusReply>
-#endif // KS_DBUS
-
-#include "actions/bootentry.h"
-#include "actions/lock.h"
-#include "kshutdown.h"
-#include "log.h"
-#include "mainwindow.h"
-#include "password.h"
-#include "progressbar.h"
-#include "utils.h"
-
 using namespace KShutdown;
 
 bool Action::m_totalExit = false;
 #ifdef KS_DBUS
-QDBusInterface *Action::m_loginInterface = 0;
+QDBusInterface *Action::m_loginInterface = nullptr;
 
-QDBusInterface *PowerAction::m_halDeviceInterface = 0;
-QDBusInterface *PowerAction::m_halDeviceSystemPMInterface = 0;
-QDBusInterface *PowerAction::m_upowerInterface = 0;
+QDBusInterface *PowerAction::m_halDeviceInterface = nullptr;
+QDBusInterface *PowerAction::m_halDeviceSystemPMInterface = nullptr;
+QDBusInterface *PowerAction::m_upowerInterface = nullptr;
 
 bool StandardAction::m_kdeShutDownAvailable = false;
-QDBusInterface *StandardAction::m_consoleKitInterface = 0;
-QDBusInterface *StandardAction::m_kdeSessionInterface = 0;
-QDBusInterface *StandardAction::m_lxqtSessionInterface = 0;
-QDBusInterface *StandardAction::m_razorSessionInterface = 0;
+QDBusInterface *StandardAction::m_consoleKitInterface = nullptr;
+QDBusInterface *StandardAction::m_kdeSessionInterface = nullptr;
+QDBusInterface *StandardAction::m_lxqtSessionInterface = nullptr;
+QDBusInterface *StandardAction::m_razorSessionInterface = nullptr;
 #endif // KS_DBUS
 
 // Base
@@ -79,11 +79,10 @@ Base::Base(const QString &id) :
 	m_canBookmark(false) {
 }
 
-Base::~Base() {
-}
+Base::~Base() = default;
 
 QWidget *Base::getWidget() {
-	return 0;
+	return nullptr;
 }
 
 void Base::readConfig(Config *config) {
@@ -125,7 +124,7 @@ void Base::setLastError() {
 // public
 
 Action::Action(const QString &text, const QString &iconName, const QString &id) :
-	U_ACTION(0),
+	U_ACTION(nullptr),
 	Base(id),
 	m_force(false),
 	m_shouldStopTimer(true),
@@ -176,7 +175,7 @@ bool Action::showConfirmationMessage() {
 	if (mainWindow->isVisible())
 		parent = mainWindow;
 	else
-		parent = 0;
+		parent = nullptr;
 
 	QPointer<QMessageBox> message = new QMessageBox(
 		QMessageBox::Warning,
@@ -186,6 +185,11 @@ bool Action::showConfirmationMessage() {
 		parent
 	);
 	message->setDefaultButton(QMessageBox::Cancel);
+	if (!icon().isNull()) {
+		int size = U_APP->style()->pixelMetric(QStyle::PM_MessageBoxIconSize);
+		message->setIconPixmap(icon().pixmap(size, size));
+	}
+
 	QAbstractButton *ok = message->button(QMessageBox::Ok);
 	ok->setIcon(icon());
 
@@ -266,7 +270,17 @@ QDBusInterface *Action::getLoginInterface() {
 }
 #endif // KS_DBUS
 
-bool Action::launch(const QString &program, const QStringList &args) {
+bool Action::launch(const QString &program, const QStringList &args, const bool detached) {
+	if (detached) {
+		U_DEBUG << "Launching detached \"" << program << "\" with \"" << args << "\" arguments" U_END;
+
+		// HACK: start detached to fix session manager hang in GNOME-based DEs
+		bool ok = QProcess::startDetached(program, args);
+		U_DEBUG << "Started OK: " << ok U_END;
+
+		return ok;
+	}
+
 	U_DEBUG << "Launching \"" << program << "\" with \"" << args << "\" arguments" U_END;
 
 	int exitCode = QProcess::execute(program, args);
@@ -335,7 +349,11 @@ ConfirmAction::ConfirmAction(QObject *parent, Action *action) :
 	setShortcut(action->shortcut());
 	setStatusTip(action->statusTip());
 	setText(action->text());
-	setToolTip(action->toolTip());
+	#if QT_VERSION >= 0x050100
+	// HACK: action->toolTip() is unusable in Qt
+	setToolTip(action->statusTip()); // for QMenu
+	#endif // QT_VERSION
+
 	connect(this, SIGNAL(triggered()), SLOT(slotFire()));
 }
 
@@ -380,7 +398,7 @@ DateTimeEdit::DateTimeEdit()
 	);
 }
 
-DateTimeEdit::~DateTimeEdit() { }
+DateTimeEdit::~DateTimeEdit() = default;
 
 // private slots:
 
@@ -409,10 +427,8 @@ DateTimeTriggerBase::DateTimeTriggerBase(const QString &text, const QString &ico
 }
 
 DateTimeTriggerBase::~DateTimeTriggerBase() {
-	if (m_edit) {
-		delete m_edit;
-		m_edit = 0;
-	}
+	delete m_edit;
+	m_edit = nullptr;
 }
 
 bool DateTimeTriggerBase::canActivateAction() {
@@ -494,7 +510,7 @@ void DateTimeTriggerBase::setState(const State state) {
 			int secsTo = now.secsTo(m_endDateTime);
 			ProgressBar *progressBar = MainWindow::self()->progressBar();
 			progressBar->setTotal(secsTo);
-			progressBar->setValue(0);
+			progressBar->setValue(-1);
 		}
 	}
 }
@@ -755,6 +771,20 @@ QDBusInterface *PowerAction::getUPowerInterface() {
 			"org.freedesktop.UPower",
 			QDBusConnection::systemBus()
 		);
+
+		if (!m_upowerInterface->isValid()) {
+			// HACK: wait for service start
+			// BUG: https://sourceforge.net/p/kshutdown/bugs/34/
+			U_DEBUG << "UPower: Trying again..." U_END;
+			delete m_upowerInterface;
+			m_upowerInterface = new QDBusInterface(
+				"org.freedesktop.UPower",
+				"/org/freedesktop/UPower",
+				"org.freedesktop.UPower",
+				QDBusConnection::systemBus()
+			);
+		}
+
 		if (m_upowerInterface->isValid())
 			U_DEBUG << "UPower backend found..." U_END;
 		else
@@ -784,7 +814,11 @@ bool PowerAction::onAction() {
 		LockAction::self()->activate(false);
 
 		// HACK: wait for screensaver
+		#if QT_VERSION >= 0x050000
+		QThread::sleep(1);
+		#else
 		::sleep(1);
+		#endif // QT_VERSION
 	}
 	
 	QDBusInterface *login = getLoginInterface();
@@ -987,7 +1021,7 @@ StandardAction::StandardAction(const QString &text, const QString &iconName, con
 		QDBusReply<bool> reply = m_razorSessionInterface->call("canLogout");
 		if (!reply.isValid() || !reply.value()) {
 			delete m_razorSessionInterface;
-			m_razorSessionInterface = 0;
+			m_razorSessionInterface = nullptr;
 			disable("No Razor-qt session found");
 		}
 	}
@@ -1001,7 +1035,7 @@ StandardAction::StandardAction(const QString &text, const QString &iconName, con
 		QDBusReply<bool> reply = m_lxqtSessionInterface->call("canLogout");
 		if (!reply.isValid() || !reply.value()) {
 			delete m_lxqtSessionInterface;
-			m_lxqtSessionInterface = 0;
+			m_lxqtSessionInterface = nullptr;
 			disable("No LXQt session found");
 		}
 	}
@@ -1174,42 +1208,26 @@ bool StandardAction::onAction() {
 			QStringList args;
 			args << "--logout";
 			args << "--no-prompt";
-			if (launch("cinnamon-session-quit", args)) {
-				// HACK: session save issue?
-				U_APP->quit();
-			
+
+			if (launch("cinnamon-session-quit", args, true))
 				return true;
-			}
 		}
 	}
 	
 	// GNOME Shell, Unity
 
-// FIXME: KDE build causes huge delay in session manager or something (?)
 	else if (Utils::isGNOME() || Utils::isUnity()) {
 		if (m_type == U_SHUTDOWN_TYPE_LOGOUT) {
 			QStringList args;
+// TODO: --force
 			args << "--logout";
 			args << "--no-prompt";
-			if (launch("gnome-session-quit", args)) {
-				// HACK: session save issue?
-				U_APP->quit();
-			
+
+			if (launch("gnome-session-quit", args, true))
 				return true;
-			}
 		}
 	}
 
-/* TODO: GNOME 2 shutdown
-	if (Utils::isGNOME()) {
-		QStringList args;
-		args << "--kill";
-		args << "--silent";
-		if (launch("gnome-session-save", args))
-			return true;
-	}
-*/
-
 	// LXDE
 
 	else if (Utils::isLXDE()) {
@@ -1249,18 +1267,8 @@ bool StandardAction::onAction() {
 		if (m_type == U_SHUTDOWN_TYPE_LOGOUT) {
 			QStringList args;
 			args << "--logout";
-			if (launch("mate-session-save", args))
-				return true;
-		}
-	}
 
-	// Openbox
-
-	else if (Utils::isOpenbox()) {
-		if (m_type == U_SHUTDOWN_TYPE_LOGOUT) {
-			QStringList args;
-			args << "--exit";
-			if (launch("openbox", args))
+			if (launch("mate-session-save", args, true))
 				return true;
 		}
 	}
@@ -1299,15 +1307,16 @@ bool StandardAction::onAction() {
 
 	// Xfce
 
-/* FIXME: causes IO error in session manager (?)
 	else if (Utils::isXfce()) {
 		switch (m_type) {
 			case U_SHUTDOWN_TYPE_LOGOUT: {
 				QStringList args;
 				args << "--logout";
-				if (launch("xfce4-session-logout", args))
+
+				if (launch("xfce4-session-logout", args, true))
 					return true;
 			} break;
+/*
 			case U_SHUTDOWN_TYPE_REBOOT: {
 				QStringList args;
 				args << "--reboot";
@@ -1324,9 +1333,9 @@ bool StandardAction::onAction() {
 				U_ERROR << "WTF? Unknown m_type: " << m_type U_END;
 
 				return false; // do nothing
+*/
 		}
 	}
-*/
 
 	// Enlightenment
 
@@ -1362,7 +1371,23 @@ bool StandardAction::onAction() {
 		return true;
 	}
 	#endif // KS_DBUS
-	
+
+	// Openbox
+
+	// NOTE: Put this after m_kdeSessionInterface call
+	// because in case of Openbox/KDE session KShutdown
+	// will detect both Openbox and KDE at the same time.
+	// ISSUE: https://sourceforge.net/p/kshutdown/feature-requests/20/
+	if (Utils::isOpenbox()) {
+		if (m_type == U_SHUTDOWN_TYPE_LOGOUT) {
+			QStringList args;
+			args << "--exit";
+
+			if (launch("openbox", args))
+				return true;
+		}
+	}
+
 	// fallback to systemd/logind/ConsoleKit/HAL/whatever
 	
 	#ifdef KS_DBUS
@@ -1512,12 +1537,6 @@ LogoutAction::LogoutAction() :
 	#ifdef Q_OS_HAIKU
 	disable("");
 	#endif // Q_OS_HAIKU
-	
-	#ifdef KS_UNIX
-// HACK:
-	if (Utils::isXfce())
-		disable("");
-	#endif // KS_UNIX
 }
 
 // RebootAction
@@ -1526,7 +1545,7 @@ LogoutAction::LogoutAction() :
 
 RebootAction::RebootAction() :
 	StandardAction(i18n("Restart Computer"), QString::null, "reboot", U_SHUTDOWN_TYPE_REBOOT),
-	m_bootEntryComboBox(0) {
+	m_bootEntryComboBox(nullptr) {
 
 #ifdef KS_NATIVE_KDE
 /* HACK: crash on KDE 4.5.0
