@@ -15,48 +15,12 @@
 // with this program; if not, write to the Free Software Foundation, Inc.,
 // 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-#include "pureqt.h"
+#include "mainwindow.h"
 
-#include <QCheckBox>
-#include <QCloseEvent>
-#include <QGroupBox>
-#include <QLayout>
-#include <QPointer>
-#include <QTimer>
-
-#ifdef KS_DBUS
-	#include <QDBusConnection>
-#endif // KS_DBUS
-
-#ifdef KS_PURE_QT
-	#include "version.h" // for about()
-
-	#include <QLabel>
-#else
-	#include <KActionCollection>
-	#include <KHelpMenu>
-	#include <KNotification>
-	#include <KNotifyConfigWidget>
-	#include <KShortcutsDialog>
-	#include <KStandardAction>
-	#include <KStandardGuiItem>
-#endif // KS_PURE_QT
-
-#ifdef KS_KF5
-	#include <KGlobalAccel>
-#endif // KS_KF5
-
-#include "actions/bootentry.h"
-#include "actions/extras.h"
-#include "actions/lock.h"
-#include "actions/test.h"
-#include "triggers/idlemonitor.h"
-#include "triggers/processmonitor.h"
 #include "bookmarks.h"
 #include "commandline.h"
-#include "infowidget.h"
+#include "config.h"
 #include "log.h"
-#include "mainwindow.h"
 #include "mod.h"
 #include "password.h"
 #include "preferences.h"
@@ -64,8 +28,36 @@
 #include "stats.h"
 #include "usystemtray.h"
 #include "utils.h"
+#include "actions/extras.h"
+#include "actions/lock.h"
+#include "actions/test.h"
+#include "triggers/idlemonitor.h"
+#include "triggers/processmonitor.h"
 
-MainWindow *MainWindow::m_instance = 0;
+#ifdef KS_PURE_QT
+	#include "version.h"
+#endif // KS_PURE_QT
+
+#include <QCloseEvent>
+#include <QPointer>
+#include <QPushButton>
+#include <QTimer>
+
+#ifdef KS_NATIVE_KDE
+	#include <KActionCollection> // #kde4
+	#include <KHelpMenu>
+	#include <KNotification>
+	#include <KNotifyConfigWidget>
+	#include <KShortcutsDialog>
+	#include <KStandardAction> // #kde4
+	#include <KStandardGuiItem>
+#endif // KS_NATIVE_KDE
+
+#ifdef KS_KF5
+	#include <KGlobalAccel>
+#endif // KS_KF5
+
+MainWindow *MainWindow::m_instance = nullptr;
 QHash<QString, Action*> MainWindow::m_actionHash;
 QHash<QString, Trigger*> MainWindow::m_triggerHash;
 QList<Action*> MainWindow::m_actionList;
@@ -87,7 +79,7 @@ MainWindow::~MainWindow() {
 
 	if (m_progressBar) {
 		delete m_progressBar;
-		m_progressBar = 0;
+		m_progressBar = nullptr;
 	}
 }
 
@@ -165,14 +157,14 @@ bool MainWindow::checkCommandLine() {
 		"</td></tr>\n";
 
 		// HACK: non-clickable links in Oxygen Style
-		table += "<tr><td colspan=\"2\"><a href=\"http://sourceforge.net/p/kshutdown/wiki/Command%20Line/\">http://sourceforge.net/p/kshutdown/wiki/Command%20Line/</a></td></tr>\n";
+		table += "<tr><td colspan=\"2\"><a href=\"https://sourceforge.net/p/kshutdown/wiki/Command%20Line/\">https://sourceforge.net/p/kshutdown/wiki/Command%20Line/</a></td></tr>\n";
 
 		table += "</table>";
 		
 		//U_DEBUG << table U_END;
 
 		QMessageBox::information( // krazy:exclude=qclasses
-			0,
+			nullptr,
 			i18n("Command Line Options"),
 			"<qt>" +
 			table +
@@ -185,7 +177,7 @@ bool MainWindow::checkCommandLine() {
 	
 	TimeOption::init();
 	
-	Action *actionToActivate = 0;
+	Action *actionToActivate = nullptr;
 	bool confirm = Utils::isArg("confirm");
 	foreach (Action *action, m_actionList) {
 		if (action->isCommandLineArgSupported()) {
@@ -226,7 +218,7 @@ bool MainWindow::checkCommandLine() {
 			}
 
 			// execute action and quit now
-			if (actionToActivate->authorize(0))
+			if (actionToActivate->authorize(nullptr))
 				actionToActivate->activate(false);
 
 			return true;
@@ -319,7 +311,7 @@ void MainWindow::init() {
 	addTrigger(new ProcessMonitor());
 #endif // KS_TRIGGER_PROCESS_MONITOR
 
-	IdleMonitor *idleMonitor = new IdleMonitor();
+	auto *idleMonitor = new IdleMonitor();
 	if (idleMonitor->isSupported())
 		addTrigger(idleMonitor);
 	else
@@ -328,9 +320,11 @@ void MainWindow::init() {
 	pluginConfig(true); // read
 }
 
-bool MainWindow::maybeShow() {
+bool MainWindow::maybeShow(const bool forceShow) {
 	if (Utils::isArg("hide-ui")) {
 		hide();
+
+// FIXME: KStatusNotifierItem is always visible
 		m_systemTray->setVisible(false);
 		
 		return true;
@@ -340,8 +334,15 @@ bool MainWindow::maybeShow() {
 	if (!menuLayout.isEmpty()) {
 		QStringList menuActions = menuLayout.split(':');
 
-		U_MENU *menu = new U_MENU();
+		auto *menu = new U_MENU();
+		#if QT_VERSION < 0x050100
 		//connect(menu, SIGNAL(hovered(QAction *)), SLOT(onMenuHovered(QAction *)));
+		#else
+		connect(menu, SIGNAL(hovered(QAction *)), SLOT(onMenuHovered(QAction *)));
+		menu->setToolTipsVisible(true);
+		#endif // QT_VERSION
+
+		bool confirm = Utils::isArg("confirm");
 
 		foreach (const QString &id, menuActions) {
 			if (id == "-") {
@@ -359,10 +360,15 @@ bool MainWindow::maybeShow() {
 			else {
 				auto *action = m_actionHash[id];
 // TODO: show confirmation dialog at cursor position (?)
-				if (action)
-					menu->addAction(new ConfirmAction(menu, action));
-				else
+				if (action) {
+					if (confirm)
+						menu->addAction(new ConfirmAction(menu, action));
+					else
+						menu->addAction(action);
+				}
+				else {
 					U_DEBUG << "Unknown ui-menu element: " << id U_END;
+				}
 			}
 		}
 
@@ -382,7 +388,10 @@ bool MainWindow::maybeShow() {
 	if (trayIconEnabled)
 		m_systemTray->setVisible(true);
 
-	if (Utils::isArg("init") || U_APP->isSessionRestored()) {
+	if (forceShow) {
+		show();
+	}
+	else if (Utils::isArg("init") || U_APP->isSessionRestored()) {
 		if (!trayIconEnabled)
 			showMinimized(); // krazy:exclude=qmethods
 	}
@@ -444,12 +453,16 @@ QStringList MainWindow::triggerList(const bool showDescription) {
 }
 
 void MainWindow::setActive(const bool yes) {
+	setActive(yes, true);
+}
+
+void MainWindow::setActive(const bool yes, const bool needAuthorization) { // private
 	if (m_active == yes)
 		return;
 
 	U_DEBUG << "MainWindow::setActive( " << yes << " )" U_END;
 
-	if (!yes && !PasswordDialog::authorize(this, i18n("Cancel"), "kshutdown/action/cancel"))
+	if (needAuthorization && !yes && !PasswordDialog::authorize(this, i18n("Cancel"), "kshutdown/action/cancel"))
 		return;
 
 	Action *action = getSelectedAction();
@@ -475,6 +488,7 @@ void MainWindow::setActive(const bool yes) {
 	
 	m_active = yes;
 	m_systemTray->updateIcon(this);
+	m_progressBar->updateTaskbar(-1, -1, false);
 
 	//U_DEBUG << "\tMainWindow::getSelectedAction() == " << action->id() U_END;
 	//U_DEBUG << "\tMainWindow::getSelectedTrigger() == " << trigger->id() U_END;
@@ -579,7 +593,7 @@ void MainWindow::setTime(const QString &trigger, const QString &time) {
 		setSelectedTrigger(trigger);
 	
 	QTime t = TimeOption::parseTime(time);
-	bool absolute = (trigger == "date-time") ? true : false;
+	bool absolute = (trigger == "date-time");
 	setTime(trigger, t, absolute);
 }
 
@@ -621,7 +635,10 @@ void MainWindow::closeEvent(QCloseEvent *e) {
 	e->ignore();
 
 	// no system tray, minimize instead
-	if (!m_systemTray->isSupported()) {
+	if (
+		!m_systemTray->isSupported() ||
+		Utils::isUnity() // HACK: QSystemTrayIcon::activated not called in Unity
+	) {
 		showMinimized(); // krazy:exclude=qmethods
 	}
 	// hide in system tray instead of close
@@ -647,7 +664,7 @@ void MainWindow::closeEvent(QCloseEvent *e) {
 
 MainWindow::MainWindow() :
 	U_MAIN_WINDOW(
-		0,
+		nullptr,
 		Qt::Window |
 		// disable "Maximize" button; no Qt::WindowMaximizeButtonHint
 		Qt::CustomizeWindowHint | Qt::WindowSystemMenuHint | Qt::WindowTitleHint | Qt::WindowMinimizeButtonHint | Qt::WindowCloseButtonHint
@@ -657,11 +674,11 @@ MainWindow::MainWindow() :
 	m_ignoreUpdateWidgets(true),
 	m_showActiveWarning(true),
 	m_showMinimizeInfo(true),
-	m_progressBar(0),
+	m_progressBar(nullptr),
 	m_lastNotificationID(QString::null),
 	m_triggerTimer(new QTimer(this)),
-	m_currentActionWidget(0),
-	m_currentTriggerWidget(0) {
+	m_currentActionWidget(nullptr),
+	m_currentTriggerWidget(nullptr) {
 
 	//U_DEBUG << "MainWindow::MainWindow()" U_END;
 
@@ -761,6 +778,10 @@ MainWindow::MainWindow() :
 		QDBusConnection::ExportScriptableSlots
 	);
 #endif // KS_DBUS
+
+	// Do not focus OK button on startup
+	// to avoid accidental action activation via Enter key.
+	m_actions->setFocus();
 }
 
 void MainWindow::addAction(Action *action) {
@@ -789,8 +810,10 @@ U_ACTION *MainWindow::createQuitAction() {
 	auto *quitAction = new U_ACTION(this);
 	quitAction->setIcon(U_STOCK_ICON("application-exit"));
 	quitAction->setShortcut(QKeySequence("Ctrl+Q"));
+	//quitAction->setShortcuts(QKeySequence::Quit <- useless);
 	connect(quitAction, SIGNAL(triggered()), SLOT(onQuit()));
 	#endif // KS_NATIVE_KDE
+
 	// NOTE: Use "Quit KShutdown" instead of "Quit" because
 	// it may be too similar to "Turn Off" in some language translations.
 	quitAction->setText(i18n("Quit KShutdown"));
@@ -798,7 +821,7 @@ U_ACTION *MainWindow::createQuitAction() {
 	return quitAction;
 }
 
-void MainWindow::initFileMenu(U_MENU *fileMenu, const bool addQuitAction) {
+void MainWindow::initFileMenu(U_MENU *fileMenu) {
 	Action *a;
 	QString id;
 	for (int i = 0; i < m_actions->count(); ++i) {
@@ -815,7 +838,7 @@ void MainWindow::initFileMenu(U_MENU *fileMenu, const bool addQuitAction) {
 		if (!a->showInMenu())
 			continue; // for
 
-		ConfirmAction *confirmAction = new ConfirmAction(this, a);
+		auto *confirmAction = new ConfirmAction(this, a);
 		if (a == LockAction::self())
 			m_confirmLockAction = confirmAction;
 
@@ -847,36 +870,43 @@ void MainWindow::initFileMenu(U_MENU *fileMenu, const bool addQuitAction) {
 	}
 	fileMenu->addSeparator();
 	fileMenu->addAction(m_cancelAction);
-	//fileMenu->addSeparator();
-
-	if (addQuitAction)
-		fileMenu->addAction(createQuitAction());
+	fileMenu->addAction(createQuitAction());
 }
 
 void MainWindow::initMenuBar() {
 	//U_DEBUG << "MainWindow::initMenuBar()" U_END;
 
-	U_MENU_BAR *menuBar = new U_MENU_BAR();
+	auto *menuBar = new U_MENU_BAR();
+
+	// HACK: Fixes Bookmarks menu and key shortcuts
+	if (Utils::isXfce())
+		menuBar->setNativeMenuBar(false);
 
 	// file menu
 
 	U_MENU *fileMenu = new U_MENU(i18n("A&ction"), menuBar);
+
 	connect(fileMenu, SIGNAL(hovered(QAction *)), SLOT(onMenuHovered(QAction *)));
+	#if QT_VERSION >= 0x050100
+	fileMenu->setToolTipsVisible(true);
+	#endif // QT_VERSION
+
 	Utils::addTitle(fileMenu, /*U_STOCK_ICON("dialog-warning")*/U_ICON(), i18n("No Delay"));
-	initFileMenu(fileMenu, true);
+	initFileMenu(fileMenu);
 	menuBar->addMenu(fileMenu);
 
-	U_MENU *systemTrayFileMenu = new U_MENU(); // need copy
-// FIXME: wrong tool tip location
-// connect(systemTrayFileMenu, SIGNAL(hovered(QAction *)), SLOT(onMenuHovered(QAction *)));
-	initFileMenu(
-		systemTrayFileMenu,
-		#ifdef KS_KF5
-		!Utils::isKDE()
-		#else
-		true
-		#endif // KS_KF5
-	);
+	auto *systemTrayFileMenu = new U_MENU(); // need copy
+
+	#if QT_VERSION < 0x050100
+	// HACK: wrong tool tip location <https://sourceforge.net/p/kshutdown/feature-requests/21/>
+	// connect(systemTrayFileMenu, SIGNAL(hovered(QAction *)), SLOT(onMenuHovered(QAction *)));
+	#else
+	connect(systemTrayFileMenu, SIGNAL(hovered(QAction *)), SLOT(onMenuHovered(QAction *)));
+	systemTrayFileMenu->setToolTipsVisible(true);
+	#endif // QT_VERSION
+
+	initFileMenu(systemTrayFileMenu);
+
 	m_systemTray->setContextMenu(systemTrayFileMenu);
 
 	// bookmarks menu
@@ -886,16 +916,21 @@ void MainWindow::initMenuBar() {
 
 	// tools menu
 
-	U_MENU *toolsMenu = new U_MENU(i18n("&Tools"), menuBar);
+	auto *toolsMenu = new U_MENU(i18n("&Tools"), menuBar);
+// TODO: add more related tools
 
 	#ifndef Q_OS_WIN32
-	toolsMenu->addAction(i18n("Statistics"), this, SLOT(onStats()));
+	auto *statsAction = toolsMenu->addAction(i18n("Statistics"), this, SLOT(onStats()));
+	statsAction->setShortcut(QKeySequence("Ctrl+Shift+S"));
 	toolsMenu->addSeparator();
 	#endif // Q_OS_WIN32
 
 #ifdef KS_PURE_QT
-	toolsMenu->addAction(i18n("Preferences"), this, SLOT(onPreferences()))
-		->setIcon(U_STOCK_ICON("configure"));
+	toolsMenu->addAction(
+		U_STOCK_ICON("configure"), i18n("Preferences"),
+		this, SLOT(onPreferences()),
+		QKeySequence::Preferences
+	);
 #endif // KS_PURE_QT
 
 #ifdef KS_NATIVE_KDE
@@ -938,7 +973,7 @@ void MainWindow::initMenuBar() {
 	#endif // KS_KF5
 #else
 	U_MENU *helpMenu = new U_MENU(i18n("&Help"), menuBar);
-	helpMenu->addAction(i18n("About"), this, SLOT(onAbout()));
+	helpMenu->addAction(i18n("About"), this, SLOT(onAbout()), QKeySequence("Ctrl+H,E,L,P"));
 	menuBar->addMenu(helpMenu);
 #endif // KS_NATIVE_KDE
 
@@ -946,12 +981,6 @@ void MainWindow::initMenuBar() {
 
 	if (Mod::getBool("ui-hide-menu-bar"))
 		menuBar->hide();
-	// HACK: Fixes Bookmarks menu and key shortcuts
-	//       (Global app menus in Unity are all f*** - it's a fact)
-	// BUG: https://bugs.launchpad.net/appmenu-qt5/+bug/1449373
-	//      https://bugs.launchpad.net/appmenu-qt5/+bug/1380702
-	else
-		menuBar->show();
 }
 
 void MainWindow::initWidgets() {
@@ -961,7 +990,7 @@ void MainWindow::initWidgets() {
 
 	QWidget *mainWidget = new QWidget();
 	mainWidget->setObjectName("main-widget");
-	QVBoxLayout *mainLayout = new QVBoxLayout(mainWidget);
+	auto *mainLayout = new QVBoxLayout(mainWidget);
 	mainLayout->setMargin(5_px);
 	mainLayout->setSpacing(10_px);
 
@@ -1076,10 +1105,16 @@ void MainWindow::setTitle(const QString &plain, const QString &html) {
 #elif defined(KS_NATIVE_KDE)
 	setCaption(plain);
 #else
+	#if QT_VERSION >= 0x050200
+	setWindowTitle(plain);
+	// NOTE: the " - KShutdown" suffix is appended automatically
+	// if QApplication::applicationDispayName is set
+	#else
 	if (plain.isEmpty())
 		setWindowTitle("KShutdown");
 	else
 		setWindowTitle(plain + " - KShutdown");
+	#endif // QT_VERSION
 #endif // KS_NATIVE_KDE
 	QString s = html.isEmpty() ? "KShutdown" : html;
 
@@ -1209,7 +1244,7 @@ void MainWindow::onAbout() {
 	// TEST: iconLabel->setPixmap(U_ICON(":/images/hi128-app-kshutdown.png").pixmap(128, 128));
 
 	QString titleText = "KShutdown " KS_FULL_VERSION;
-	QString buildText = "Build: " KS_BUILD;
+	QString buildText = KS_RELEASE_DATE;
 	if (Config::isPortable())
 		buildText += " | Portable";
 	auto *titleLabel = new QLabel(
@@ -1221,11 +1256,11 @@ void MainWindow::onAbout() {
 	titleLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
 
 	QString releaseNotes =
-		"http://kshutdown.sourceforge.net/releases/" KS_FILE_VERSION ".html";
+		"https://kshutdown.sourceforge.io/releases/" KS_FILE_VERSION ".html";
 	auto *aboutLabel = new QLabel(
 		"<qt>" +
 		i18n("A graphical shutdown utility") + "<br />" \
-		"<a href=\"" KS_HOME_PAGE "\">kshutdown.sf.net</a><br />" \
+		"<a href=\"" KS_HOME_PAGE "\">kshutdown.sourceforge.io</a><br />" \
 		"<br />" \
 		"<a href=\"" + releaseNotes + "\">" + i18n("What's New?") + "</a><br />" \
 		"</qt>"
@@ -1250,8 +1285,7 @@ void MainWindow::onAbout() {
 	aboutLayout->addStretch();
 
 QString licenseText =
-R"(<qt><pre>
-This program is <b>free software</b>; you can redistribute it and/or modify
+R"(<qt>This program is <b>free software</b>; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
@@ -1259,9 +1293,9 @@ the Free Software Foundation; either version 2 of the License, or
 This program is distributed in the hope that it will be useful,
 but <b>WITHOUT ANY WARRANTY</b>; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-<a href="http://www.gnu.org/licenses/gpl.html">GNU General Public License</a> for more details. (<a href="http://tldrlegal.com/l/gpl2">tl;dr</a>)</pre></qt>)";
+<a href="http://www.gnu.org/licenses/gpl.html">GNU General Public License</a> for more details. (<a href="http://tldrlegal.com/l/gpl2">tl;dr</a>)</qt>)";
 
-	auto *licenseLabel = new QLabel(licenseText);
+	auto *licenseLabel = new QLabel(licenseText.replace("\n", "<br />"));
 	licenseLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
 	licenseLabel->setOpenExternalLinks(true);
 
@@ -1338,7 +1372,9 @@ void MainWindow::onCheckTrigger() {
 	// activate action
 	Trigger *trigger = getSelectedTrigger();
 	if (trigger->canActivateAction()) {
-		setActive(false);
+		// NOTE: 2nd "false" fixes https://sourceforge.net/p/kshutdown/bugs/33/
+		setActive(false, false);
+
 		Action *action = getSelectedAction();
 		if (action->isEnabled()) {
 			U_DEBUG << "Activate action: force=" << m_force->isChecked() U_END;
@@ -1426,7 +1462,7 @@ void MainWindow::onPreferences() {
 
 	// DOC: http://www.kdedevelopers.org/node/3919
 	QPointer<Preferences> dialog = new Preferences(this);
-	if ((dialog->exec() == Preferences::Accepted) || Utils::isGTKStyle()) {
+	if (dialog->exec() == Preferences::Accepted) {
 		dialog->apply();
 		
 		m_progressBar->setVisible(m_active && getSelectedTrigger()->supportsProgressBar() && Config::progressBarEnabled());
@@ -1442,8 +1478,8 @@ void MainWindow::onStats() {
 	delete dialog;
 }
 
-void MainWindow::onStatusChange(const bool aUpdateWidgets) {
-	//U_DEBUG << "onStatusChange(" << aUpdateWidgets << ")" U_END;
+void MainWindow::onStatusChange(const bool forceUpdateWidgets) {
+	//U_DEBUG << "onStatusChange(" << forceUpdateWidgets << ")" U_END;
 
 	Action *action = getSelectedAction();
 	Trigger *trigger = getSelectedTrigger();
@@ -1464,7 +1500,7 @@ void MainWindow::onStatusChange(const bool aUpdateWidgets) {
 	else
 		type = InfoWidget::Type::Info;
 	
-	if (aUpdateWidgets) {
+	if (forceUpdateWidgets) {
 		updateWidgets();
 		
 		// do not override status set in "updateWidgets()"
@@ -1488,10 +1524,10 @@ void MainWindow::onTriggerActivated(int index) {
 	Trigger *trigger = getSelectedTrigger();
 	m_currentTriggerWidget = trigger->getWidget();
 	if (m_currentTriggerWidget) {
-		static_cast<QVBoxLayout *>(m_triggerBox->layout())->insertWidget(1, m_currentTriggerWidget);
+		dynamic_cast<QVBoxLayout *>(m_triggerBox->layout())->insertWidget(1, m_currentTriggerWidget);
 		m_currentTriggerWidget->show();
 	}
-	
+
 	m_triggers->setToolTip(trigger->toolTip());
 
 	onStatusChange(true);
