@@ -18,17 +18,18 @@
 #ifndef KSHUTDOWN_PREFERENCES_H
 #define KSHUTDOWN_PREFERENCES_H
 
+#include "pureqt.h"
 #include "udialog.h"
 
-class PasswordPreferences;
+#include <QCheckBox>
 
-class QCheckBox;
+class PasswordPreferences;
 
 class Preferences: public UDialog {
 	Q_OBJECT
 public:
 	explicit Preferences(QWidget *parent);
-	virtual ~Preferences();
+	virtual ~Preferences() = default;
 	void apply();
 private:
 	Q_DISABLE_COPY(Preferences)
@@ -40,6 +41,9 @@ private:
 	QCheckBox *m_noMinimizeToSystemTrayIcon;
 	QCheckBox *m_progressBarEnabled;
 	QCheckBox *m_systemTrayIconEnabled;
+	#ifndef KS_KF5
+	QCheckBox *m_useThemeIconInSystemTray;
+	#endif // !KS_KF5
 	//QWidget *createActionsWidget();
 	QWidget *createGeneralWidget();
 	QWidget *createSystemTrayWidget();
@@ -51,9 +55,12 @@ private:
 private slots:
 	void onFinish(int result);
 	void onProgressBarEnabled(bool enabled);
-#ifdef KS_NATIVE_KDE
-	void onKDERelatedSettings();
-#endif // KS_NATIVE_KDE
+	#ifdef KS_KF5
+	void onSystemSettings();
+	#endif // KS_KF5
+	#ifndef KS_KF5
+	void onUseThemeIconInSystemTraySelected(bool selected);
+	#endif // !KS_KF5
 };
 
 #endif // KSHUTDOWN_PREFERENCES_H
