@@ -15,11 +15,10 @@
 // with this program; if not, write to the Free Software Foundation, Inc.,
 // 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-#include <QDateTimeEdit>
+#include "idlemonitor.h"
 
 #include "../mainwindow.h"
 #include "../progressbar.h"
-#include "idlemonitor.h"
 
 #ifdef Q_OS_WIN32
 	#ifndef WIN32_LEAN_AND_MEAN
@@ -31,11 +30,6 @@
 	#include "../actions/lock.h"
 #endif // Q_OS_WIN32
 
-#ifdef KS_DBUS
-	#include <QDBusInterface>
-	#include <QDBusReply>
-#endif // KS_DBUS
-
 #ifdef KS_NATIVE_KDE
 	#include <KIdleTime>
 #endif // KS_NATIVE_KDE
@@ -78,7 +72,7 @@ IdleMonitor::IdleMonitor()
 	setToolTip(i18n("Use this trigger to detect user inactivity\n(example: no mouse clicks)."));
 }
 
-IdleMonitor::~IdleMonitor() { }
+IdleMonitor::~IdleMonitor() = default;
 
 bool IdleMonitor::canActivateAction() {
 	getSessionIdleTime();
@@ -141,7 +135,7 @@ void IdleMonitor::setState(const State state) {
 
 		ProgressBar *progressBar = MainWindow::self()->progressBar();
 		progressBar->setTotal(getMaximumIdleTime());
-		progressBar->setValue(0);
+		progressBar->setValue(-1);
 
 #ifdef KS_NATIVE_KDE
 		KIdleTime::instance()->simulateUserActivity();
