@@ -15,15 +15,10 @@
 // with this program; if not, write to the Free Software Foundation, Inc.,
 // 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-#include "pureqt.h"
-
 #include "udialog.h"
+
 #include "utils.h"
 
-// TODO: clean up all headers
-
-#include <QVBoxLayout>
-
 // public:
 
 UDialog::UDialog(QWidget *parent, const QString &windowTitle, const bool simple) :
@@ -31,6 +26,8 @@ UDialog::UDialog(QWidget *parent, const QString &windowTitle, const bool simple)
 	//U_DEBUG << "UDialog::UDialog()" U_END;
 	setWindowTitle(windowTitle);
 
+// TODO: AA_DisableWindowContextHelpButton #Qt5.10
+
 #ifdef KS_KF5
 	if (simple) {
 		m_dialogButtonBox = new QDialogButtonBox(QDialogButtonBox::Close);
@@ -74,7 +71,3 @@ UDialog::UDialog(QWidget *parent, const QString &windowTitle, const bool simple)
 	m_rootLayout->addWidget(mainWidget);
 	m_rootLayout->addWidget(m_dialogButtonBox);
 }
-
-UDialog::~UDialog() {
-	//U_DEBUG << "UDialog::~UDialog()" U_END;
-}
