@@ -15,21 +15,20 @@
 // with this program; if not, write to the Free Software Foundation, Inc.,
 // 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
+#include "usystemtray.h"
+
 #include "config.h"
 #include "mainwindow.h"
-#include "pureqt.h"
-#include "usystemtray.h"
 #include "utils.h"
 
 #include <QPainter>
 
+// TODO: better support for dock(ish) taskbars (Windows 7/Unity)
+
 // public:
 
 USystemTray::USystemTray(MainWindow *mainWindow)
 	: QObject(mainWindow)
-	#ifdef KS_PURE_QT
-	, m_applyGeometryHack(true)
-	#endif // KS_PURE_QT
 {
 	//U_DEBUG << "USystemTray::USystemTray()" U_END;
 
@@ -37,12 +36,12 @@ USystemTray::USystemTray(MainWindow *mainWindow)
 	m_sessionRestored = false;
 	#ifdef KS_KF5
 	m_trayIcon = new KStatusNotifierItem(mainWindow);
+	m_trayIcon->setCategory(KStatusNotifierItem::ApplicationStatus);
+	m_trayIcon->setStandardActionsEnabled(false);
 // FIXME: m_trayIcon->setToolTipIconByPixmap(QIcon(":/images/kshutdown.png"));
 	m_trayIcon->setToolTipIconByName("kshutdown");
 	#else
 	m_trayIcon = new KSystemTrayIcon(mainWindow);
-// TODO: "KShutdown" caption in System Tray Settings dialog (Entries tab).
-// Currently it's lower case "kshutdown".
 	#endif // KS_KF5
 #endif // KS_NATIVE_KDE
 
@@ -61,10 +60,6 @@ USystemTray::USystemTray(MainWindow *mainWindow)
 	U_DEBUG << "USystemTray::isSupported:" << isSupported() U_END;
 }
 
-USystemTray:: ~USystemTray() {
-	//U_DEBUG << "USystemTray::~USystemTray()" U_END;
-}
-
 void USystemTray::info(const QString &message) const {
 	#ifdef KS_KF5
 	m_trayIcon->showMessage("KShutdown", message, "dialog-information");
@@ -75,12 +70,12 @@ void USystemTray::info(const QString &message) const {
 
 bool USystemTray::isSupported() const {
 	#ifdef KS_KF5
+// TODO: use classic QSystemTrayIcon as fallback if KStatusNotifierItem is unsupported
 // TODO: test other DE
 	// Blacklist: GNOME Shell, Unity
-	return Utils::isKDE();
+	return Utils::isKDE() || Utils::isXfce();
 	#else
 	return
-		!Utils::isUnity() &&
 		QSystemTrayIcon::isSystemTrayAvailable() &&
 		// HACK: MATE launches KShutdown before system tray panel is created
 		!(Utils::isMATE() && m_sessionRestored);
@@ -94,8 +89,11 @@ void USystemTray::setContextMenu(QMenu *menu) const {
 void USystemTray::setToolTip(const QString &toolTip) const {
 	#ifdef KS_KF5
 	m_trayIcon->setToolTipTitle("KShutdown");
-// TODO: remove leading/duplicated "KShutdown"
-	m_trayIcon->setToolTipSubTitle((toolTip == m_trayIcon->toolTipTitle()) ? "" : toolTip);
+	m_trayIcon->setToolTipSubTitle(
+		(toolTip == m_trayIcon->toolTipTitle())
+		? ""
+		: QString(toolTip).replace("<qt>KShutdown<br><br>", "<qt>") // remove leading/duplicated "KShutdown" text
+	);
 	#else
 	m_trayIcon->setToolTip(toolTip);
 	#endif // KS_KF5
@@ -114,65 +112,65 @@ void USystemTray::setVisible(const bool visible) {
 }
 
 void USystemTray::updateIcon(MainWindow *mainWindow) {
-	// HACK: We need to show an empty system tray icon first to get proper geometry() value later.
-	// Wrong/unknown geometry (or something) causes bad icon alignment and background repaint issues...
-	#ifdef KS_PURE_QT
-	if (m_applyGeometryHack) {
-		m_applyGeometryHack = false;
+	#ifndef KS_KF5
+	bool active = mainWindow->active();
+	bool bw = Config::blackAndWhiteSystemTrayIcon();
 
+	// HACK: We need to show an empty system tray icon first
+	// to fix wrong icon alignment and background repaint issues...
+	if (m_applyIconHack) {
+		m_applyIconHack = false;
 		if (Utils::isMATE() && Config::systemTrayIconEnabled()) {
 			m_trayIcon->setIcon(mainWindow->windowIcon()); // suppress Qt warning
 			m_trayIcon->show();
 		}
 	}
-	#endif // KS_PURE_QT
-
-	#ifndef KS_KF5
-	bool active = mainWindow->active();
-	bool bw = Config::blackAndWhiteSystemTrayIcon();
-	#endif // KS_KF5
+	#endif // !KS_KF5
 	
 	// get base icon
-	
-	#ifndef KS_KF5
-	QIcon icon;
-	#ifdef KS_UNIX
-	if (Utils::isKDE())
-		icon = U_STOCK_ICON("system-shutdown");
-	else
-		icon = mainWindow->windowIcon();
-	#else
-	icon = mainWindow->windowIcon();
-	#endif // KS_UNIX
-	#endif // KS_KF5
 
 	#ifdef KS_KF5
 	Q_UNUSED(mainWindow)
+// TODO: option
+// FIXME: setIconByPixmap does not work...
 	if (Utils::isKDE())
 		m_trayIcon->setIconByName("system-shutdown");
 	else
 		m_trayIcon->setIconByName("kshutdown");
-// FIXME: setIconByPixmap does not work...
+
+/* TODO: hide if inactive #5.x
+	bool active = mainWindow->active();
+	m_trayIcon->setStatus(active ? KStatusNotifierItem::Active : KStatusNotifierItem::Passive);
+*/
 	#else
 	// convert base icon to pixmap
 
-	int w = 22;
-	int h = 22;
-	QRect iconSize = m_trayIcon->geometry();
-	// HACK: https://bugreports.qt-project.org/browse/QTBUG-24683
-	if (!iconSize.size().isEmpty() && (iconSize.width() <= 64) && (iconSize.height() <= 64)) {
-		//U_DEBUG << "USystemTray::updateIcon: system tray icon size: " << iconSize U_END;
-		w = qBound(22, iconSize.width(), 64);
-		h = qBound(22, iconSize.height(), 64);
-	}
-/*
-	else {
-		U_DEBUG << "USystemTray::updateIcon: using safe tray icon size; reported geometry = " << iconSize U_END;
-	}
-*/
+	QIcon icon;
+	#ifdef KS_UNIX
+	if (!active && Config::readBool("General", "Use Theme Icon In System Tray", true)) {
+		icon = U_STOCK_ICON("system-shutdown");
+		if (icon.isNull()) {
+			U_DEBUG << "System theme icon not found in: " << icon.themeName() U_END;
+			icon = mainWindow->windowIcon(); // fallback
+		}
+		// HACK: fixes https://sourceforge.net/p/kshutdown/bugs/27/
+		else {
+			m_trayIcon->setIcon(icon);
 
+			return; // no image effects
+		}
+	}
+	else {
+		icon = mainWindow->windowIcon();
+	}
+	#else
+	icon = U_ICON(":/images/hi16-app-kshutdown.png");
+	#endif // KS_UNIX
+
+	int w = 64_px;
+	int h = 64_px;
 	QPixmap pixmap = icon.pixmap(w, h);
-	QImage image = pixmap.toImage().convertToFormat(QImage::Format_ARGB32_Premultiplied);
+	QImage image = pixmap.toImage().convertToFormat(QImage::Format_ARGB32);
 
 	// add some effects
 
@@ -212,21 +210,6 @@ void USystemTray::updateIcon(MainWindow *mainWindow) {
 		}
 	}
 
-	// add overlay icons (active trigger/action)
-	
-	w = pixmap.width() / 2;
-	if (active && (w >= 11)) {
-		h = pixmap.height() / 2;
-
-		QPainter p(&image);
-		p.setOpacity(0.7);
-		
-		// left/bottom
-		mainWindow->getSelectedAction()->icon().paint(&p, 0, h, w, h);
-		// right/bottom
-		mainWindow->getSelectedTrigger()->icon().paint(&p, w, h, w, h);
-	}
-
 	m_trayIcon->setIcon(QPixmap::fromImage(image));
 	#endif // KS_KF5
 }
@@ -248,12 +231,23 @@ void USystemTray::onRestore(QSystemTrayIcon::ActivationReason reason) {
 
 	if (reason == QSystemTrayIcon::Trigger) {
 		MainWindow *mainWindow = MainWindow::self();
-		if (mainWindow->isVisible()) {
+		if (mainWindow->isVisible() && !mainWindow->isMinimized()) {
 			mainWindow->hide();
 		}
 		else {
+			#ifdef Q_OS_WIN32
+			if (mainWindow->isMinimized()) {
+				// HACK: activateWindow() does not work and causes funny bugs
+				mainWindow->showNormal();
+			}
+			else {
+				mainWindow->show();
+				mainWindow->activateWindow();
+			}
+			#else
 			mainWindow->show();
 			mainWindow->activateWindow();
+			#endif // Q_OS_WIN32
 		}
 	}
 }
