@@ -18,25 +18,21 @@
 #ifndef KSHUTDOWN_USYSTEMTRAY_H
 #define KSHUTDOWN_USYSTEMTRAY_H
 
-#include <QObject>
-
 #ifdef KS_KF5
 	#include <KStatusNotifierItem>
 #elif defined(KS_PURE_QT)
 	#include <QSystemTrayIcon>
 #else
-	#include <KSystemTrayIcon>
+	#include <KSystemTrayIcon> // #kde4
 #endif // KS_KF5
 
 class MainWindow;
 
-class QMenu;
-
 class USystemTray: public QObject {
 	Q_OBJECT
 public:
-	explicit USystemTray(MainWindow *parent);
-	virtual ~USystemTray();
+	explicit USystemTray(MainWindow *mainWindow);
+	virtual ~USystemTray() = default;
 	void info(const QString &message) const;
 	bool isSupported() const;
 	void setContextMenu(QMenu *menu) const;
@@ -49,11 +45,11 @@ private:
 	#ifdef KS_KF5
 	KStatusNotifierItem *m_trayIcon;
 	#elif defined(KS_PURE_QT)
-	bool m_applyGeometryHack;
 	QSystemTrayIcon *m_trayIcon;
 	#else
 	KSystemTrayIcon *m_trayIcon;
 	#endif // KS_KF5
+	bool m_applyIconHack = true;
 	bool m_sessionRestored;
 #ifdef KS_PURE_QT
 private slots:
