@@ -1,14 +1,14 @@
 #!/bin/bash
 
-if [ ! -f "./tools/make-version.sh" ]; then
-	echo "Usage: ./tools/`basename $0`"
+if [ ! -d "src" ]; then
+	echo "Usage: ./tools/$(basename $0)"
 	exit 1
 fi
 
 # make version number
 
 ./tools/make-version.sh
-KS_FILE_VERSION=`sed 1!d tools/VERSION`
+KS_FILE_VERSION=$(sed 1!d VERSION)
 
 # init variables
 
@@ -18,8 +18,12 @@ KS_ZIP="kshutdown-source-$KS_FILE_VERSION.zip"
 
 # clean before copy
 
-rm -f ./kshutdown
-rm -f ./kshutdown-qt
+rm -f ./kshutdown-*-win32.exe ./kshutdown-portable-*-win32.7z
+rm -fR ./kshutdown-portable
+rm -fR ./src/debug ./src/release
+rm -f ./src/.qmake.stash \
+	./src/Makefile.Debug ./src/Makefile.Release \
+	./src/object_script.kshutdown-qt.Debug ./src/object_script.kshutdown-qt.Release
 rm -fR "$KS_DIR"
 rm -fR "$KS_DIST_DIR"
 
@@ -43,7 +47,6 @@ cp -r "patches" "$KS_DIR"
 rm -f po/*.po~
 cp -r "po" "$KS_DIR"
 
-cp -r ".kdev4" "$KS_DIR"
 cp -r "src" "$KS_DIR"
 cp -r "tools" "$KS_DIR"
 
